# The Lollipop Cloud Project

The Lollipop Cloud project is an attempt to make hosting personal internet services such as a website, contact list, remote file storage, or a calendar more accessible to users through open source technology and [ARM boards (link)](https://en.wikipedia.org/wiki/ARM_architecture). It allows for anyone with an ARM computer to host their own services.

(The above blurb came from [our website (link)](https://lollipopcloud.solutions/), in case you're just joining us.)

## Recommended Hardware
* a single-board computer (SBC) like [Pine64](https://www.pine64.org/) or [Orange Pi (link)](http://www.orangepi.org/) with [Armbian](https://www.armbian.com/) installed.
* a means to work with the SBC (monitor/keyboard, serial adapter, ssh via ethernet)
* wifi adapter, cell modem, [GPS](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/hardware/gps.md), [RTC (Real Time Clock)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/hardware/rtc.md), [Bluetooth Serial Terminal](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/hardware/bluetooth_terminal.md), other hardware you need for your custom setup. see also: [Hardware Considerations (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/hardware_notes.md)

## Initial Setup
[Setup For Beginners!! (link)](for-beginners.md): If you are new to installing Linux, or would like a little extra help walking through the initial creation of your Lollipop, please take a look our document written especially for beginners. Come back here and skip down to the next section ([Networking](#Networking)) when you're ready.

If you're not using the [link for beginners](for-beginners.md), you can start here:
* [First Boot (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/first_boot.md)
* [Base Setup (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/base_setup.md)


## Networking Setup

- [Network Manager (networking setup tool) (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/network_manager.md)
- [Modem Manager (3G/LTE modems) (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/modem_manager.md)
- [FirewallD (firewall/routing) (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/firewalld.md)
- [Unbound (Non ISP DNS) (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/unbound.md)
- VPN Options
    - [Private Internet Access (VPN) (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/pia.md)
    - [vpn.ac (VPN) (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/vpn_ac.md)
    - [VPN Autoconnect (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/vpn_autoconnect.md)

## Fundamental Tools

- [Cockpit (recommended!) (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/cockpit.md): simple browser-based management console/UI
- [Chrony (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/chrony.md): clock synchronization
- [Borg Backups (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/borg.md): simple, effective, efficient backups
- [Docker (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/docker.md): containerize your services
- [Let's Encrypt (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/lets_encrypt.md): SSL/TLS certificates
- [Incron (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/incron.md): inotify-based cron, useful for automatic service reloads
- [Caddy (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/caddy.md): web server/proxy
- [Pi Hole (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/pi_hole.md): ad-blocking to save bandwidth and data
- [Searx (link)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/searx.md): self-hosted search engine

## Additional Services

- [Postgresl](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/postgres.md): database management, required for NextCloud, Gogs, Wallabag, TT-RSS, and Turtl, if desired, and possibly additional services
- [Monitoring](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/monitoring.md): basic monitoring with munin
- [ElasticBeats (incomplete)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/elasticbeats.md): Logs/Monitoring
- [NextCloud](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/nextcloud.md): file syncing, alternative to Dropbox
- [Syncthing](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/syncthing.md): sync for large numbers or large sized files, an alternative to NextCloud
- [Gogs](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/gogs.md): self-hosted git, alternative to GitHub
- [Gitea (incomplete)](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/gitea.md): self-hosted git
- [Wallabag](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/wallabag.md): save websites for later, alternative to Read it Later or Pocket
- [TT-RSS](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/ttrss.md): self-hosted RSS reader, alternative to Google Reader
- [Turtl](https://git.lollipopcloud.solutions/lollipop-cloud/lolipop_lan_cloud/src/branch/master/docs/armbian/turtl.md): self-hosted notes synchronization, alternative to Evernote or OneNote
